@@ -8,6 +8,8 @@ from ._standards.ksic10 import KSIC10, KSIC10_to_ISIC4
 from ._standards.nace2 import NACE2, NACE2_to_ISIC4
 from ._standards.nacebel2003 import NACEBEL2003, NACEBEL2003_to_NACEBEL2008
 from ._standards.nacebel2008 import NACEBEL2008, NACEBEL2008_to_NACE2
+from ._standards.naf1 import NAF1, NAF1_to_NAF2
+from ._standards.naf2 import NAF2, NAF2_to_NACE2
 from ._standards.naics2017 import NAICS2017, NAICS2017_to_ISIC4
 from ._standards.skd2002 import SKD2002, SKD2002_to_NACE2, SKD2002_to_SKD2008
 from ._standards.skd2008 import SKD2008, SKD2008_to_SKD2002
@@ -30,5 +32,7 @@ ToISIC4 = ComposedGraph(
         CNAE2_to_ISIC4,
         NACEBEL2003_to_NACEBEL2008,
         NACEBEL2008_to_NACE2,
+        NAF1_to_NAF2,
+        NAF2_to_NACE2,
     ],
 )
